{% block header -%}
:mod:`{{ fullname }}`
======={% for c in fullname %}={% endfor %}
{%- endblock %}

.. currentmodule:: {{ fullname }}

{% block attributes %}
{% if attributes %}
Attributes
----------

.. autosummary::
   :toctree:
{% for item in attributes %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block functions %}
{% if functions %}
Functions
---------

.. autosummary::
   :toctree:
{% for item in functions %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block classes %}
{% if classes %}
Classes
-------

.. autosummary::
   :toctree:
   :template: class.rst
{% for item in classes %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block exceptions %}
{% if exceptions %}
Exceptions
----------

.. autosummary::
   :toctree:
{% for item in exceptions %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}

{% block modules %}
{% if modules %}
Submodules
----------

.. autosummary::
   :toctree:
   :template: custom-module-template.rst

{% for item in modules %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}
